@@ -5,11 +5,14 @@ from __future__ import absolute_import
 # import apis into api package
 from mux_python.api.assets_api import AssetsApi
 from mux_python.api.delivery_usage_api import DeliveryUsageApi
+from mux_python.api.dimensions_api import DimensionsApi
 from mux_python.api.direct_uploads_api import DirectUploadsApi
 from mux_python.api.errors_api import ErrorsApi
 from mux_python.api.exports_api import ExportsApi
 from mux_python.api.filters_api import FiltersApi
+from mux_python.api.incidents_api import IncidentsApi
 from mux_python.api.live_streams_api import LiveStreamsApi
 from mux_python.api.metrics_api import MetricsApi
+from mux_python.api.real_time_api import RealTimeApi
 from mux_python.api.url_signing_keys_api import URLSigningKeysApi
 from mux_python.api.video_views_api import VideoViewsApi
